Some initial thoughts after using PL10.0.1/Win for 4 days, compared to latest PL9, with the following config:
i7-14700KF (no iGPU), 32GB RAM, desktop RTX 4070 (12GB VRAM), NVIDIA driver 596.36 (a bit old), 4k monitor, NVme disks (2TB system+4TB photos), high quality preview and DeepPRIME rendering enabled, up to 4 hours of continuous usage time.
batch export performance at about the same level as in PL9, i.e. around 10mpx/s for XD3 and 20-25mpx/s for DP3 on average, dealing with Nikon Z8 14-bit raws. Checked up to 400 NEFs per export. (EDIT: with export #threads=2)
about the same processing lags
perhaps slightly faster startup
no resource usage problems so far
PhotoLab log a bit cluttered with āPrivate tag BodyType not available. You must not call GetBodyType before BodyType private tag is injected in Exif, we default to Body_Unknown. Check your logic.ā entries
no crash dumps, errors in Application EventLog for PL, or RTX 4070 resets so far
The only āproblemā so far is that applying presets to few hundred of photos takes time without any notice from PL, probably the same as with PL9. Something to take care before clicking anything else.
Itās hard to make any precise comparative performance tests since PL9, especially with AI masks, because some optimizations, caching and cache manegement make any comparisons very difficult. Iāve seen some AI edits exported 3 times faster than for the first time. People with less GPU VRAM may experience even more execution time variance.
Tested also AI masks, Depth masks, and some other new features, except for Color Grading and Dust Removal (could be interesting how it works with headshots). No major problems so far on two sets of raws, each about 400 photos. Some AI masks look more precise than in PL9. Got to rethink Selective Tones usage with the new Whites slider ā maybe Iāll have to rework some of my older edits. Not sure if some auto-tuning is not done by NVIDIA/Microsoft/DxO, even if you disable (external) NVIDIA telemetry. Situation looks similar to some old Rolls-Royce engine horse-power specification: enough.
That said, Iāve risked today switching from PL9 to PL10 in āproduction modeā, still keeping PL7,8,9 for safety reasons. Note that Iām normally using only a limited set of PL features, so for those who use a lot of LocalAdjustments or DAM functionality the situation might be different. Probably there are some minor problems still to sort out, but so far it looks usable to me, unlike early PL9 versions.
Full confirmation from my side (Ryzen 9950x3d CPU, 64GB RAM, GPU RTX5080, newest NVIDIA driver) . Many thanks to Wlodek for the very detailed and well structured report.
As far as I have seen until now after 3 days of experimental work performance of PL10 in general is very similar to PL9. No objections so far, although still a bit of delay occurs when doing manual mask refinements at high magnification.
New AI-masks are working sufficiently. Depth mask and color brush are a reasonable step forward and make things more comfortable compared to PL9. The selectivity control of masks (saturation+luminance) is also a rather helpful feature.
Color grading is a nice option to change the mood of an image but I donāt use this frequently and it is for me therefore not an essential feature (but better have it than need itā¦).
It is not clear to me whether the white-slider is something I really need besides the well known traditional highlight control. I also regard this as a nice-to-have instead of a must.
In summary PL10 is a kind of evolutionary proceeding but donāt expect phenomenal wow-moments. In my opinion DxO still has a way to go in order to achieve a 100% satisfying performance but I know in my case thatās a sort of whining at a high level.
When trial period is finished I will finally switch over to PL10.
One thing puzzled me in PL10/Win ā in Edit ā Preferences ā Performance ā Display and process it says: āMaximum number of simultaneously processed images(1 recommended)ā, while in PL9,8,7 DxO recommended 2. In my case PL10 installation has set the value to 2, as it was in my PL9 config. Also PL10 docs show screenshots probably coming from PL9, which Iāve reported it to DxO as a doc bug. I think theyāve changed the recommended value down from 2 to 1 for the sake of more intense AI VRAM usage, but perhaps itās aftermath of early PL9 problems ā until PL9.7 or so Iāve set the value to 1 but reversed back to 2 later. The batch export performance data in my previous post is for #threads=2, which so far didnāt cause any problems in my case (tested with XD3 and some photos with AI LA, including depth masks).
This is not specific to PL10 (in fact I tested it in PL9 as well) but in my testing, the display(s) used make a significant difference in performance with PhotoLab.
On M1 MacBook Pro w/ 16GB of RAM, a simple test of just changing the Color/B&W Rendering from B&W to Color:
Using the MacBookās internal display, the switch from B&W to Color is just about instant.
If I use a 24" display it takes 1-2 seconds to make the switch from B&W to color.
If I use two 32" displays, it takes anywhere from 3-7 seconds.
Obviously more vram & gpu power has to be used the larger the display so thatās not surprising (even if disappointing).
However, my main takeaway here that it sheds light, maybe, on the discrepancies we see from user to user on this forum. While I see mention of computer specs, I donāt see mention of display sizes nor how many displays are being used.
That is mentioned in C1 release notes, e.g. https://support.captureone.com/hc/en-us/articles/38417592388381-Capture-One-16-8-5-release-notes :
" 4K monitors For optimal performance on 4K monitors, we recommend doubling the initial specifications due to the increased computational demands. Additionally, investing in a high-performance GPU with ample VRAM is highly recommended for these configurations to handle the intensive graphics processing.
"
I havenāt seen anything similar for DxO but probably it also applies to some extent.
I am on a MB Pro M4 w/ 48G. I should have experienced no meaningful performance drop from PL9 to PL10, but I had a massive one that made it unworkable for me. I mean, in PL9 I rarely had to wait for any brush to catch up with my strokes, or an imageās edits to load, etc. I would describe it as pretty much lightning fast. In PL10, the brushes seemed almost unusable (I was āediting blindā), and all images took a long time to display their edits. For me, the solution turned out to be that PL10 had defaulted to āAuto Selection (Apple Neural Engine)ā in Preferences/Advanced/AI acceleration. I switched it to GPU Apple M4 Pro, and experienced a massive improvement in speed ā and stability ā across all functions.
Itās still not as fast for me as PL9, but itās livable now.
So happy to see everyone chiming in with their experiences. Quite helpful information.
For me, the things that are easily quantifiable like export times, are not something I care much about. I can set it to do its thing and work on other stuff. Itās the lagginess that is very irritating. As mentioned, itās not a deal breaker, but still inexcusable when no other apps I run have these issues.
Early experience (Intel ARC B570 w/ 10GB)
In my system. Windows 11.
Performance on GUI / Editing is okay (not slower than PL9). May even faster.
Pre-defined mask - detection first all pre-defined - great in real life usage (1 step)
The people detection (hair, face, etc) is a blessing.
Export performance seems (i measure it) is the same as in PL9 latest.
Stable
Observations (early, not to scientific)
AI memory management - Dynamic optimalization of memory usage
As i see, its try to keep GPU memory usage minimum as possible. I see like 3.1 GB of usage, even in complex scenarios.
I guess its may works fine with 4GB GPU with that.
Increased CPU usage.
May CPU performance count more then in PL9 (?)
GPU usage is in āsaw waveā
Seems suggested paralel export now: 1. I still use 4, but may its make less sense in the case if AI mask used. (?)
Optimizing AI models runs in every driver update
Interesting part
I do a lot of performance test with PL 9.9 - see here. Budget GPU for PL - #23 by andras.csore. And seems Export in PL10 (and PL9.12.1) its faster vs PL9 9.9 (in my system, with the same photos, same settings).
Examples:
DP3 export, No mask, 88 test photo - PL 9.9 vs PL10 - 06:27 vs 02:22 (!)
DP3 XD export, No mask, 88 test photo - PL 9.9 vs PL10 - 23:02 vs 07:40 (!)
With AI masks, the performance improvement less. 4 AI (pre-defined) mask: 07:28 vs 06:10. With 8 AI pre-defined and 12 non-AI mask is the same. (approx 08:10)
I dont know, why and how. May Intel driver is better. May OpenVINO (Intel) AI provider is better, may PL handling of this is better. May all of it.
For me Photolab remains too irritating (performance wise) for me to tolerate it - the quality is fine itās just not a nice experience using it. I agree - these days I donāt think its acceptable to have to go into the menu to switch previews on and off - at least have a button to do that in the task bar. Unfortunately my M5 Studio doesnāt come for another 3 weeks so I wonāt have a chance to test it on that - but on my M4 MacBook Pro it is just not a nice experience. Sticking with LRc for now.
Mark, specifically what regarding AI features (masks?) has improved?
My earlier issues w/ AI masks involved sloppy edge detection. Have you noticed any improvement there?
mwsilvers
(Mark - New Jersey, USA, Win10, RTX 4060, PL9, FP8, VP5, Nikon Zf )
54
On my aging Windows 10 machine from 2016 upgraded with a new power supply, an RTX 4060 graphics card and a WD Black 2TB SDD card, the improvements to AI masking in PL10 include faster and smoother mask selection, better selection accuracy along with improved edge detection, much better people selection with the ability to accurately select eyes, lips, hair, etc., and faster AI mask export timing, especially with the addition of XD3. Subject detection of complex subjects is now excellent and to my eyes, on a par with Lightroom. Since updating to PL10 I have not had any export errors.
In my experience, sky masking still needs the most work . There are considerable problems masking the sky around trees, wires, and buildings with complex shapes and extrusions. When masking sky areas I find using control lines is still the best option. The next best option for masking sky areas seems to be the new control masking tool, but I have found using it successfully tends to need harder edges between the sky and non sky areas.
Before upgrading I strongly suggest you download and test the trial version to ensure it meets your expectations.
Thatās actually a brilliant suggestion. Stalls while using a masking brush are not a deal-breaker for me, but they are the biggest friction point for me; one of just a couple really bitter pills I choose to swallow in Photolab.
Being able to toggle the high-resolution preview on/off with a keyboard command and/or a very well-placed button⦠would be a spoonful of sugar with our medicine.
I canāt compare it with PL9 as I passed on that release (because the win box I had at the time was getting old (i5, 32MB DDR3, 1050 w 12MB) and even PL8 was a bit slow with 24MP raw. I didnāt care a lot about exporting speed as this was a hobby so I could start a bulk export and walk away) but there was 4-5 seconds between previewing one file and previewing the next. I was about to buy a 45MP camera, figured that would be even slower so I built a new box. Cheap compared to a new telephoto lens - and I see it as a camera accessory.
Anyway, on that new box with PL8 exporting 45MP raws to JPG was around 4 seconds per (plus a few seconds overhead) - and on PL10 itās a bit faster. Not a lot: exporting 5 photos went from 22sec on PL8 to 20sec on PL10. No AI masking to keep things the same, but leveling, cropping, color correction, curves - the usual stuff.
Lucky for me that PL9 came out when it did as it prompted me to build a new win box - and that was just as prices were starting to skyrocket.
Stenis
(Sten-à ke Sändh (Sony, Win 11, PL 6, CO 16, PM Plus 6, XnView))
57
Also saw that performance when exporting without any mask is really surprisingly fast.
I“m really pleased with this upgrade and all the masking improvennts.